#!/bin/bash
# Initial author           : Natim <natim@user.sourceforge.net>
# Maintainer : Son|c (emmanuel.bailleul@cegetel.net)
#
# ftp://sunsite.cnlab-switch.ch/mirror/OpenLDAP/openldap-release/openldap-2.4.20.tgz
#

#
# what package is going to be built
#
softname1='openldap'
softname2='openldap-client'
softversion='2.4.20'
packageversion='64.1'

#
# ZenWalk standard: CPU type and architecture, as well as the
# version number of ZenWalk this package is made for (on?).
#
arch='i486'
cpu='i686'

#
# the package 'destination'
#
prefix=/usr

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
numjobs='-j2'

#
# parameters needed for the build process
#
buildir=$(pwd)
srcpkg="$buildir/openldap-$softversion.tgz"
src="$buildir/openldap-$softversion"
package1="$softname1-$softversion-$arch-$packageversion"
package2="$softname2-$softversion-$arch-$packageversion"
dest1="$buildir/$package1"
dest2="$buildir/$package2"

#
# prepare the build result directory
#
rm -rf $dest1 $dest2
mkdir -p $dest1
mkdir -p $dest2
mkdir -p $dest1/install
mkdir -p $dest2/install
mkdir -p $dest1/$prefix/src/$softname1-$softversion
mkdir -p $dest2/$prefix/src/$softname2-$softversion

#
# put slack-desc in place. Either a supplied one, or some default
# text.
#
cat <<EOF > $dest1/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
openldap: OpenLDAP server (LDAP server)
openldap: 
openldap: OpenLDAP Software is an open source implementation of
openldap: the Lightweight Directory Access Protocol.
openldap: 
openldap: 
openldap: 
openldap:
openldap: 
openldap: 
openldap: 
EOF

cat <<EOF > $dest2/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
openldap-client: OpenLDAP clients (LDAP clients, libs & include files)
openldap-client: 
openldap-client: OpenLDAP Software is an open source implementation of
openldap-client: the Lightweight Directory Access Protocol.
openldap-client: 
openldap-client: 
openldap-client: 
openldap-client:
openldap-client: 
openldap-client: 
openldap-client: 
EOF


#
# extract the source code
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar jxvf $srcpkg
# tgz    : tar zxvf $srcpkg
#
cd $buildir
tar zxvf $srcpkg
cd $src

#
# configure package for compilation
#
export CFLAGS="-O2 -march=$arch -mtune=$cpu"  
      
./configure \
--prefix=$prefix \
--sysconfdir=/etc \
--localstatedir=/var \
--mandir=/usr/man
#--disable-static \
#--disable-slapd \
#--disable-slurpd
     
#
# make package
#
    make depend
    make

#
# install package to the target directory
#
    make install DESTDIR=$dest2

# Backward compatibility with openldap 2.3.x libs
cd $dest2/usr/lib
ln -s libldap-2.4.so.2.5.3 libldap-2.3.so.0
ln -s libldap_r-2.4.so.2.5.3 libldap_r-2.3.so.0
ln -s liblber-2.4.so.2.5.3 liblber-2.3.so.0

# Create working default config
mv $dest2/var/openldap-data/DB_CONFIG.example $dest2/var/openldap-data/DB_CONFIG.new
sed -i '/core\.schema/a \
#include\t/etc/openldap/schema/collective.schema \
#include\t/etc/openldap/schema/corba.schema \
#include\t/etc/openldap/schema/core.schema \
#include\t/etc/openldap/schema/cosine.schema \
#include\t/etc/openldap/schema/duaconf.schema \
#include\t/etc/openldap/schema/dyngroup.schema \
#include\t/etc/openldap/schema/inetorgperson.schema \
#include\t/etc/openldap/schema/java.schema \
#include\t/etc/openldap/schema/misc.schema \
#include\t/etc/openldap/schema/nadf.schema \
#include\t/etc/openldap/schema/nis.schema \
#include\t/etc/openldap/schema/openldap.schema \
#include\t/etc/openldap/schema/ppolicy.schema \
' $dest2/etc/openldap/slapd.conf


#
# add 'default' files
#
mkdir -p $dest2/usr/doc/$softname1-$softversion
cd $src
cp -a \
ANNOUNCEMENT CHANGES COPYRIGHT INSTALL LICENSE README \
$dest2/usr/doc/$softname1-$softversion

#
# Strip Executables
# (Comment out these lines if debugging info is needed)
#
( cd $dest2
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Compress Man Pages
#
( cd $dest2/usr/man
  find . -name "*.?" | xargs gzip -9
)

# Fix broken symlinks
( cd $dest2/usr/man/man1
  for i in $(find . -type l) ; do
	  target=`readlink $i`
	  rm -f $i
	  ln -sf $target.gz $i.gz
  done
)
( cd $dest2/usr/man/man3
  for i in $(find . -type l) ; do
	  target=`readlink $i`
	  rm -f $i
	  ln -sf $target.gz $i.gz
  done
)
( cd $dest2/usr/man/man5
  for i in $(find . -type l) ; do
	  target=`readlink $i`
	  rm -f $i
	  ln -sf $target.gz $i.gz
  done
)
#
# put the ZenWalk build in the right directory
#
cd $buildir
cp build-$softname1.sh $dest1/$prefix/src/$softname1-$softversion
cp build-$softname1.sh $dest2/$prefix/src/$softname2-$softversion

#
# set target permissions
#
chown -R root:root $dest2

cd $dest2
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Let's split packages
mkdir -p $dest1/etc/openldap
mkdir -p $dest1/usr/man/man5
mkdir -p $dest1/usr/include
cd $dest2
mv etc/openldap/schema $dest1/etc/openldap
mv etc/openldap/DB_CONFIG* $dest1/etc/openldap
mv etc/openldap/slapd.conf* $dest1/etc/openldap
mv var $dest1/
cd usr
mv libexec sbin doc $dest1/usr
mv man/man5/slap* $dest1/usr/man/man5/
mv man/man8 $dest1/usr/man/
mv include/slap* $dest1/usr/include

# Create startup script
mkdir -p $dest1/etc/rc.d
cat << "EOF" > $dest1/etc/rc.d/rc.slapd.new
#!/bin/sh
#
## init script for slapd

slapd_start() {
        if [ -x /usr/libexec/slapd ]; then
                echo -n "Starting slapd :  "
                echo "/usr/libexec/slapd"
                /usr/libexec/slapd 2>/dev/null
        fi
}

slapd_stop() {
        killall slapd
}

slapd_restart() {
        sh $0 stop
	sleep 1
        sh $0 start
}

case "$1" in
        'start')
                slapd_start
                ;;
        'stop')
                slapd_stop
                ;;
        'restart')
                slapd_restart
                ;;
        *)
                echo "usage $0 start|stop|restart"
esac
EOF
chmod 644 $dest1/etc/rc.d/rc.slapd.new

mkdir $dest1/etc/rc.d/desc.d
echo slapd:The OpenLDAP Directory Server:slapd > $dest1/etc/rc.d/desc.d/slapd.txt
chown -R root.root $dest1/etc/rc.d

# Postinstall files

cat << "EOD" > $dest1/install/doinst.sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/openldap/slapd.conf.new
config etc/rc.d/rc.slapd.new
config var/openldap-data/DB_CONFIG.new

EOD

mv $dest1/etc/openldap/slapd.conf $dest1/etc/openldap/slapd.conf.new

cat << "EOD" > $dest2/install/doinst.sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/openldap/ldap.conf.new

EOD

mv $dest2/etc/openldap/ldap.conf $dest2/etc/openldap/ldap.conf.new


# Generate dep files
cd $dest1
depfinder $dest1 > $buildir/$package1.dep
echo ",openldap-client" >> $buildir/$package1.dep
cd $dest2
depfinder $dest2 > $buildir/$package2.dep

#
# real packaging work: 
#
cd $dest1
makepkg -l y -c n ../$package1.txz
#mv $package1.txz $buildir
cd $dest2
makepkg -l y -c n ../$package2.txz
#mv $package2.txz $buildir

#
# computes the md5sum signature for the packages
#
cd $buildir
md5sum $package1.txz > $package1.md5
md5sum $package2.txz > $package2.md5 

# Create source files
echo "ftp://sunsite.cnlab-switch.ch/mirror/OpenLDAP/openldap-release/openldap-2.4.20.tgz" > $package1.src
echo "http://download.zenwalk.org/people/emmanuel/$softname1-$softversion/build-$softname1.sh" >> $package1.src

echo "ftp://sunsite.cnlab-switch.ch/mirror/OpenLDAP/openldap-release/openldap-2.4.20.tgz" > $package2.src
echo "http://download.zenwalk.org/people/emmanuel/$softname1-$softversion/build-$softname1.sh" >> $package2.src
# Create cat file (private use)
echo "extra/s" > $package1.cat
echo "l" > $package2.cat
